==> munit-maven-plugins-common-2.2.2-sources.jar: org/mule/munit/plugin/maven/runner/model/SuiteResult.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.plugin.maven.runner.model;


import static java.util.Optional.of;
import static org.apache.commons.lang3.StringUtils.isNotBlank;

import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;
import java.util.function.Predicate;
import java.util.stream.Collectors;

import org.apache.commons.lang3.StringUtils;

/**
 * <p>
 * A model that represents the result of a suite run
 * </p>
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public class SuiteResult {

  private String suitePath;

  private boolean suiteFinished = false;
  private boolean runtimeStartFailed = false;

  private String cause;
  private Map<String, TestResult> tests = new HashMap<String, TestResult>();
  private long time;
  private boolean suiteFailed;
  private boolean suiteError;
  private String parameterization;

  public void setRuntimeStartFailed(boolean runtimeStartFailed) {
    this.runtimeStartFailed = runtimeStartFailed;
  }

  public void setCause(String newCause) {
    if (StringUtils.isEmpty(cause)) {
      this.cause = newCause;
    }
  }

  public void add(String testName, TestResult testResult) {
    tests.put(testName, testResult);
  }

  public void setSuitePath(String suitePath) {
    this.suitePath = suitePath;
  }

  public void setSuiteFinished(boolean suiteFinished) {
    this.suiteFinished = suiteFinished;
  }

  public boolean isSuiteFinished() {
    return suiteFinished;
  }

  public boolean isRuntimeStartFailed() {
    return runtimeStartFailed;
  }

  public String getCause() {
    return cause;
  }

  public int getNumberOfProcessedTests() {
    return countTests(TestResult::isFinished);
  }

  public int getNumberOfIgnores() {
    return countTests(TestResult::isIgnored);
  }

  public int getNumberOfFailures() {
    return countTests(TestResult::hasFailed);
  }

  public int getNumberOfErrors() {
    return countTests(TestResult::hasError);
  }

  public int getNumberOfTests() {
    return tests.size();
  }

  public TestResult getTest(String string) {
    return tests.get(string);

  }

  public Optional<TestResult> getRunningTest() {
    return tests.values().stream().filter(test -> !test.isFinished()).findFirst();
  }

  public Collection<TestResult> getTests() {
    return tests.values();
  }

  public String getSuitePath() {
    return suitePath;
  }

  public boolean hasFailed() {
    return suiteFailed || findAnyTest(TestResult::hasFailed);
  }

  public boolean hasError() {
    return runtimeStartFailed || suiteError || findAnyTest(TestResult::hasError);
  }

  public boolean isIgnored() {
    return !tests.isEmpty() && tests.values().stream().allMatch(TestResult::isIgnored);
  }

  public List<TestResult> getFailingTests() {
    return filterTests(TestResult::hasFailed);
  }

  public List<TestResult> getErrorTests() {
    return filterTests(TestResult::hasError);
  }

  public void setTime(long time) {
    this.time = time;
  }

  public long getTime() {
    return time;
  }

  public void setSuiteFailed(boolean suiteFailed) {
    this.suiteFailed = suiteFailed;
  }

  public boolean isSuiteFailed() {
    return suiteFailed;
  }

  public void setSuiteError(boolean suiteError) {
    this.suiteError = suiteError;
  }

  public boolean isSuiteError() {
    return suiteError;
  }

  public void setParameterization(String parameterization) {
    this.parameterization = parameterization;
  }

  public Optional<String> getParameterization() {
    return isNotBlank(parameterization) ? of(parameterization) : Optional.empty();
  }

  private int countTests(Predicate<TestResult> predicate) {
    return (int) tests.values().stream().filter(predicate).count();
  }

  private boolean findAnyTest(Predicate<TestResult> predicate) {
    return tests.values().stream().anyMatch(predicate);
  }

  private List<TestResult> filterTests(Predicate<TestResult> predicate) {
    return tests.values().stream().filter(predicate).collect(Collectors.toList());
  }
}

==> munit-maven-plugins-common-3.2.1-sources.jar: org/mule/munit/plugin/maven/runner/model/SuiteResult.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.plugin.maven.runner.model;


import static java.util.Optional.of;
import static org.apache.commons.lang3.StringUtils.isNotBlank;

import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;
import java.util.function.Predicate;
import java.util.stream.Collectors;

import org.apache.commons.lang3.StringUtils;

/**
 * <p>
 * A model that represents the result of a suite run
 * </p>
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public class SuiteResult {

  private String suitePath;

  private boolean suiteFinished = false;
  private boolean runtimeStartFailed = false;

  private String cause;
  private Map<String, TestResult> tests = new HashMap<String, TestResult>();
  private long time;
  private boolean suiteFailed;
  private boolean suiteError;
  private String parameterization;

  public void setRuntimeStartFailed(boolean runtimeStartFailed) {
    this.runtimeStartFailed = runtimeStartFailed;
  }

  public void setCause(String newCause) {
    if (StringUtils.isEmpty(cause)) {
      this.cause = newCause;
    }
  }

  public void add(String testName, TestResult testResult) {
    tests.put(testName, testResult);
  }

  public void setSuitePath(String suitePath) {
    this.suitePath = suitePath;
  }

  public void setSuiteFinished(boolean suiteFinished) {
    this.suiteFinished = suiteFinished;
  }

  public boolean isSuiteFinished() {
    return suiteFinished;
  }

  public boolean isRuntimeStartFailed() {
    return runtimeStartFailed;
  }

  public String getCause() {
    return cause;
  }

  public int getNumberOfProcessedTests() {
    return countTests(TestResult::isFinished);
  }

  public int getNumberOfIgnores() {
    return countTests(TestResult::isIgnored);
  }

  public int getNumberOfFailures() {
    if (isSuiteFailed()) {
      return 1;
    }
    return countTests(TestResult::hasFailed);
  }

  public int getNumberOfErrors() {
    if (isSuiteError()) {
      return 1;
    }
    return countTests(TestResult::hasError);
  }

  public int getNumberOfTests() {
    if (isSuiteFailed() || isSuiteError()) {
      return 1;
    }
    return tests.size();
  }

  public TestResult getTest(String string) {
    return tests.get(string);

  }

  public Optional<TestResult> getRunningTest() {
    return tests.values().stream().filter(test -> !test.isFinished()).findFirst();
  }

  public Collection<TestResult> getTests() {
    return tests.values();
  }

  public String getSuitePath() {
    return suitePath;
  }

  public boolean hasFailed() {
    return suiteFailed || findAnyTest(TestResult::hasFailed);
  }

  public boolean hasError() {
    return runtimeStartFailed || suiteError || findAnyTest(TestResult::hasError);
  }

  public boolean isIgnored() {
    return !tests.isEmpty() && tests.values().stream().allMatch(TestResult::isIgnored);
  }

  public List<TestResult> getFailingTests() {
    return filterTests(TestResult::hasFailed);
  }

  public List<TestResult> getErrorTests() {
    return filterTests(TestResult::hasError);
  }

  public void setTime(long time) {
    this.time = time;
  }

  public long getTime() {
    return time;
  }

  public void setSuiteFailed(boolean suiteFailed) {
    this.suiteFailed = suiteFailed;
  }

  public boolean isSuiteFailed() {
    return suiteFailed;
  }

  public void setSuiteError(boolean suiteError) {
    this.suiteError = suiteError;
  }

  public boolean isSuiteError() {
    return suiteError;
  }

  public void setParameterization(String parameterization) {
    this.parameterization = parameterization;
  }

  public Optional<String> getParameterization() {
    return isNotBlank(parameterization) ? of(parameterization) : Optional.empty();
  }

  private int countTests(Predicate<TestResult> predicate) {
    return (int) tests.values().stream().filter(predicate).count();
  }

  private boolean findAnyTest(Predicate<TestResult> predicate) {
    return tests.values().stream().anyMatch(predicate);
  }

  private List<TestResult> filterTests(Predicate<TestResult> predicate) {
    return tests.values().stream().filter(predicate).collect(Collectors.toList());
  }

}
